@@ -24,9 +24,10 @@ LsMediaAlbumArt::LsMediaAlbumArt(QString name, SystemPlayer* player) :
     applySettings();
 }
 
-void LsMediaAlbumArt::paint(QPainter *painter, const QStyleOptionGraphicsItem*,
+void LsMediaAlbumArt::paint(QPainter *painter, const QStyleOptionGraphicsItem* option,
                             QWidget*)
 {
+    painter->setClipRect(option->exposedRect);
     if (!m_AlbumArt.isNull()){
         painter->drawPixmap(0,0,m_AlbumArt);
     }
